SnapATAC2
=========

![PyPI](https://img.shields.io/pypi/v/snapatac2)
![PyPI - Downloads](https://img.shields.io/pypi/dm/snapatac2)
![Continuous integration](https://github.com/kaizhang/SnapATAC2/workflows/Continuous%20integration/badge.svg)
![GitHub Repo stars](https://img.shields.io/github/stars/kaizhang/SnapATAC2?style=social)

SnapATAC2 is the successor of the SnapATAC R package, featuring:

- Faster and less memory usage, scale to >1M cells.
- Improved dimension reduction and sampling algorithm.

Read the [Documentation](https://kzhang.org/SnapATAC2/). 